<?php
namespace Bookmify;

use Bookmify\Helper;
use Bookmify\HelperAdmin;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}


class Coupons{

	const PAGE_ID = 'bookmify_coupons';
	
	private $per_page;
	/**
	 * @since 1.0.0
	 * @access public
	*/
	public function __construct() {
		$this->assignValToVar();
		add_action( 'admin_menu', [ $this, 'registerAdminMenu' ], 20 );
		
		
		
		
		add_action( 'wp_ajax_ajaxQueryEditCoupon', [$this, 'ajaxQueryEditCoupon'] );
		add_action( 'wp_ajax_ajaxQueryDeleteCoupon', [$this, 'ajaxQueryDeleteCoupon'] );
		add_action( 'wp_ajax_ajaxQueryInsertOrUpdateCoupon', [$this, 'ajaxQueryInsertOrUpdateCoupon'] );
		
	}
	
	public function assignValToVar(){
		$this->per_page = get_option('bookmify_be_coupons_pp', 10);
	}
	
	/**
	 * @since 1.0.0
	 * @access public
	*/
	public function registerAdminMenu() {

		add_submenu_page(
			BOOKMIFY_MENU,
			esc_html__( 'Coupons', 'bookmify' ),
			esc_html__( 'Coupons', 'bookmify' ),
			'bookmify_be_read_coupons',
			self::PAGE_ID,
			[ $this, 'displayCouponsPage' ]
		);
	}
	
	public function displayCouponsPage() {
		global $wpdb;

		echo HelperAdmin::bookmifyAdminContentStart();
		?>
		
		<div class="bookmify_be_content_wrap bookmify_be_coupons_page">
			<div class="bookmify_be_page_title">
				<h3><?php echo esc_html($this->get_page_title()); ?><span class="count"><?php echo Helper::bookmifyItemsCount('coupons');?></span></h3>
				<div class="bookmify_be_add_new_item bookmify_be_add_new_coupon">
					<a href="#" class="bookmify_button add_new bookmify_add_new_button">
						<span class="text"><?php esc_html_e('Add New Coupon','bookmify');?></span>
						<span class="plus">
							<span class="icon"></span>
							<span class="bookmify_be_loader small">
								<span class="loader_process">
									<span class="ball"></span>
									<span class="ball"></span>
									<span class="ball"></span>
								</span>
							</span>
						</span>
					</a>
				</div>
			</div>
			<div class="bookmify_be_page_content">

				<div class="bookmify_be_coupons">
					
					<!-- Coupon Header -->
					<div class="bookmify_be_coupons_header">
						<div class="bookmify_be_coupons_header_in">
							<span class="list_title"><?php esc_html_e('Title', 'bookmify');?></span>
							<span class="list_code"><?php esc_html_e('Code', 'bookmify');?></span>
							<span class="list_discount"><?php esc_html_e('Discount', 'bookmify');?></span>
							<span class="list_deduction"><?php esc_html_e('Deduction', 'bookmify');?></span>
							<span class="list_limit"><?php esc_html_e('Limit', 'bookmify');?></span>
							<span class="list_sdate"><?php esc_html_e('Start Date', 'bookmify');?></span>
							<span class="list_edate"><?php esc_html_e('End Date', 'bookmify');?></span>
							<span class="list_status"><?php esc_html_e('Status', 'bookmify');?></span>
						</div>
					</div>
					<!-- /Coupon Header -->
					
					<!-- Coupon List -->
					<div class="bookmify_be_coupons_list">
						<?php echo wp_kses_post($this->couponsList()); ?>
					</div>
					<!-- /Coupon Header -->
					
				</div>
				
			</div>
			<?php echo Helper::clonableFormCoupon(); ?>
		</div>
		<?php echo HelperAdmin::bookmifyAdminContentEnd();
		
	}
	

	/*
	 * @since 1.0.0
	 * @access public
	*/
	public function couponsList(){
		global $wpdb;
		
		$query 			= "SELECT * FROM {$wpdb->prefix}bmify_coupons ORDER BY title,id";
		
		$results 		= $wpdb->get_results( $query);
		

		$html = '<div class="bookmify_be_list coupon_list">';
		if(count($results) == 0){
			$html .= Helper::bookmifyBeNoItems();
		}
		foreach($results as $result){
			$stat	= $result->status;
			switch($stat){
				case 'active': 	$status = esc_html__('open', 'bookmify'); 	break;
				default: 		$status = esc_html__('closed', 'bookmify'); break;
			}
			$html .= '<div class="bookmify_be_list_item coupon_item" data-coupon-id="'.$result->id.'">
						<div class="bookmify_be_list_item_in">
							<div class="bookmify_be_list_item_header">
								<div class="header_in">
									<div class="info_holder">
										<div class="info_in">
											<span class="coupon_title">'.$result->title.'</span>
											<span class="coupon_code">'.$result->code.'</span>
											<span class="coupon_discount">'.$result->discount.'%</span>
											<span class="coupon_deduction">'.$result->deduction.'</span>
											<span class="coupon_limit">'.$result->usage_limit.'</span>
											<span class="coupon_sdate">'.date_i18n(get_option('bookmify_be_date_format', 'd F, Y'), strtotime($result->date_limit_start)).'</span>
											<span class="coupon_edate">'.date_i18n(get_option('bookmify_be_date_format', 'd F, Y'), strtotime($result->date_limit_end)).'</span>
											<span class="coupon_status"><span class="'.$stat.'"><span>'.$status.'</span></span></span>
										</div>
									</div>

									<div class="buttons_holder">
										<div class="btn_item btn_edit">
											<a href="#" class="bookmify_be_edit">
												<img class="bookmify_be_svg edit" src="'.BOOKMIFY_ASSETS_URL.'img/edit.svg" alt="" />
												<img class="bookmify_be_svg checked" src="'.BOOKMIFY_ASSETS_URL.'img/checked.svg" alt="" />
												<span class="bookmify_be_loader small">
													<span class="loader_process">
														<span class="ball"></span>
														<span class="ball"></span>
														<span class="ball"></span>
													</span>
												</span>
											</a>
										</div>
										<div class="btn_item">
											<a href="#" class="bookmify_be_delete" data-entity-id="'.$result->id.'">
												<img class="bookmify_be_svg" src="'.BOOKMIFY_ASSETS_URL.'img/delete.svg" alt="" />
												<span class="bookmify_be_loader small">
													<span class="loader_process">
														<span class="ball"></span>
														<span class="ball"></span>
														<span class="ball"></span>
													</span>
												</span>
											</a>
										</div>
									</div>
								</div>
							</div>
								
						</div>
					</div>';
			
		}
		
		$html .= '</div>';

		return $html;
	}
	public function ajaxQueryInsertOrUpdateCoupon(){
		global $wpdb;
		$isAjaxCall 			= false;
		
		// **************************************************************************************************************************
		// UPDATE 
		// **************************************************************************************************************************
		if ($_POST['couponID'] != '') {
			$couponID		= esc_sql($_POST['couponID']);
			$couponTitle 	= esc_sql($_POST['couponTitle']);
			$couponRate 	= esc_sql($_POST['couponRate']);
				
			$wpdb->query($wpdb->prepare( "UPDATE {$wpdb->prefix}bmify_coupons SET title=%s, rate=%f WHERE id=%d", $couponTitle, $couponRate, $couponID));

		
		
		}else{
			$couponTitle 	= esc_sql($_POST['couponTitle']);
			$couponRate 	= esc_sql($_POST['couponRate']);
				
			$wpdb->query($wpdb->prepare( "INSERT INTO {$wpdb->prefix}bmify_coupons (title, rate) VALUES (%s,%f)", $couponTitle, $couponRate));
			
			
		}
		$isAjaxCall = true;
		$query 		= "SELECT * FROM {$wpdb->prefix}bmify_coupons ORDER BY title,id";
		$results 	= $wpdb->get_results( $query);

		$html 		= '<div class="bookmify_be_list coupon_list">';
		if(count($results) == 0){
			$html .= Helper::bookmifyBeNoItems();
		}
		foreach($results as $result){
			$html .= '<div class="bookmify_be_list_item coupon_item bookmify_be_animated" data-coupon-id="'.$result->id.'">
						<div class="bookmify_be_list_item_in">
							<div class="bookmify_be_list_item_header">
								<div class="header_in">
									<div class="info_holder">
										<div class="info_in">
											<span class="coupon_name">'.$result->title.'</span>
											<span class="coupon_rate">'.$result->rate.'</span>
										</div>
									</div>

									<div class="buttons_holder">
										<div class="btn_item btn_edit">
											<a href="#" class="bookmify_be_edit">
												<img class="bookmify_be_svg edit" src="'.BOOKMIFY_ASSETS_URL.'img/edit.svg" alt="" />
												<img class="bookmify_be_svg checked" src="'.BOOKMIFY_ASSETS_URL.'img/checked.svg" alt="" />
												<span class="bookmify_be_loader small">
													<span class="loader_process">
														<span class="ball"></span>
														<span class="ball"></span>
														<span class="ball"></span>
													</span>
												</span>
											</a>
										</div>
										<div class="btn_item">
											<a href="#" class="bookmify_be_delete" data-entity-id="'.$result->id.'">
												<img class="bookmify_be_svg" src="'.BOOKMIFY_ASSETS_URL.'img/delete.svg" alt="" />
												<span class="bookmify_be_loader small">
													<span class="loader_process">
														<span class="ball"></span>
														<span class="ball"></span>
														<span class="ball"></span>
													</span>
												</span>
											</a>
										</div>
									</div>
								</div>
							</div>

						</div>
					</div>';

		}

		$html .= '</div>';
			
		$buffy = '';
		if ( $html != NULL ) {
			$buffy .= $html; 
		}

		// remove whitespaces form the ajax HTML
		$search = array(
			'/\>[^\S ]+/s',  // strip whitespaces after tags, except space
			'/[^\S ]+\</s',  // strip whitespaces before tags, except space
			'/(\s)+/s'       // shorten multiple whitespace sequences
		);
		$replace = array(
			'>',
			'<',
			'\\1'
		);
		$buffy = preg_replace($search, $replace, $buffy);

		$buffyArray = array(
			'bookmify_be_data' 		=> $buffy,
			'number'				=> Helper::bookmifyItemsCount('coupons')
		);

		if ( true === $isAjaxCall ){die(json_encode($buffyArray));} 
		else{return json_encode($buffyArray);}
	}
	
	
	

	
	
	
	/**
	 * @since 1.0.0
	 * @access public
	*/
	public function ajaxQueryDeleteCoupon(){
		global $wpdb;
		$id 			= '';
		$isAjaxCall 	= false;
		if(!empty($_POST['bookmify_coupon_id'])){
			$isAjaxCall = true;
			$id 		= $_POST['bookmify_coupon_id'];
			$wpdb->query($wpdb->prepare( "DELETE FROM {$wpdb->prefix}bmify_services_coupons WHERE coupon_id=%d", $id));
			$wpdb->query($wpdb->prepare( "DELETE FROM {$wpdb->prefix}bmify_coupons WHERE id=%d", $id));
			
			
			$buffyArray = array(
				'number'				=> Helper::bookmifyItemsCount('coupons'),
			);

			if ( true === $isAjaxCall ){die(json_encode($buffyArray));} 
			else{return json_encode($buffyArray);}
		}
	}
	
	
	
	
	
	
	
	
	
	public function ajaxQueryEditCoupon(){
		global $wpdb;
		$isAjaxCall 				= false;
		$html 						= '';
		
		if (!empty($_POST['bookmify_data'])) {
			$isAjaxCall 			= true;
			$id 					= $_POST['bookmify_data'];

			// SELECT
			$id 					= esc_sql($id);
			$query 					= "SELECT * FROM {$wpdb->prefix}bmify_coupons WHERE id=".$id;
			$coupons	 			= $wpdb->get_results( $query, OBJECT  );
			
			
			foreach($coupons as $coupon){
				$ID					= $coupon->id;
				$couponTitle		= $coupon->title;
				$couponCode			= $coupon->code;
				$couponDiscount		= (float)$coupon->discount;
				$couponDeduction	= (float)$coupon->deduction;
				$couponULimit		= (int)$coupon->usage_limit;
				$couponInfo			= $coupon->info;
				$couponDLS			= $coupon->date_limit_start;
				$couponDLE			= $coupon->date_limit_end;
				$couponDLS			= date_i18n(get_option('bookmify_be_date_format', 'd F, Y'), strtotime($coupon->date_limit_start));
				$couponDLE			= date_i18n(get_option('bookmify_be_date_format', 'd F, Y'), strtotime($coupon->date_limit_end));
				$html .= '<div class="bookmify_be_popup_form_wrap" data-entity-id="'.$ID.'">
							
							<div class="bookmify_be_popup_form_position_fixer">
								<div class="bookmify_be_popup_form_bg">
									<div class="bookmify_be_popup_form">

										<div class="bookmify_be_popup_form_header">
											<h3>'.esc_html__('Edit Coupon','bookmify').'</h3>
											<span class="closer"></span>
										</div>

										<div class="bookmify_be_popup_form_content">
											<div class="bookmify_be_popup_form_content_in">

												<div class="bookmify_be_popup_form_fields">

													<form autocomplete="off">
														
														<div class="input_wrap_row">
															<div class="input_wrap">
																<label><span class="title">'.esc_html__('Title','bookmify').'<span>*</span></span></label>
																<input class="coupon_title required_field" type="text" value="'.$couponTitle.'" />
															</div>
														</div>

														<div class="input_wrap_row">
															<div class="input_wrap">
																<label><span class="title">'.esc_html__('Code','bookmify').'<span>*</span></span></label>
																<input class="coupon_code required_field" type="text" value="'.$couponCode.'" />
															</div>
														</div>

														<div class="input_wrap_row">
															<div class="input_wrap">
																<label><span class="title">'.esc_html__('Discount %','bookmify').'</span></label>
																<input class="coupon_discount" type="number" value="'.$couponDiscount.'" />
															</div>
														</div>

														<div class="input_wrap_row">
															<div class="input_wrap">
																<label><span class="title">'.esc_html__('Deduction','bookmify').'</span></label>
																<input class="coupon_deduction" type="number" value="'.$couponDeduction.'" />
															</div>
														</div>

														<div class="input_wrap_row">
															<div class="input_wrap">
																<label><span class="title">'.esc_html__('Limit Usage','bookmify').'</span></label>
																<input class="coupon_limit" type="number" value="'.$couponULimit.'" />
															</div>
														</div>

														<div class="input_wrap_row daterange">
															<input class="date_limit_start" type="hidden" value="'.$couponDLS.'" />
															<input class="date_limit_end" type="hidden" value="'.$couponDLE.'" />
															<div class="input_wrap">
																<label><span class="title">'.esc_html__('Date Limit','bookmify').'</span></label>
																<input class="coupon_date_limit" type="text" value="" />
															</div>
														</div>
														<div class="input_wrap_row">
															<div class="input_wrap">
																<label><span class="title">'.esc_html__('Info','bookmify').'</span></label>
																<textarea class="coupon_info" placeholder="'.esc_html__('Some info for internal usage', 'bookmify').'">'.$couponInfo.'</textarea>
															</div>
														</div>

													</form>

												</div>
											</div>
										</div>
										
										<div class="bookmify_be_popup_form_button">
											<a class="save" href="#">
												<span class="text">'.esc_html__('Save','bookmify').'</span>
												<span class="save_process">
													<span class="ball"></span>
													<span class="ball"></span>
													<span class="ball"></span>
												</span>
											</a>
											<a class="cancel" href="#">'.esc_html__('Cancel','bookmify').'</a>
										</div>

									</div>
								</div>
							</div>
						</div>';
			}
		}
		
		$buffy = '';
		if ( $html != NULL ) {
			$buffy .= $html; 
		}

		// remove whitespaces form the ajax HTML
		$search = array(
			'/\>[^\S ]+/s',  // strip whitespaces after tags, except space
			'/[^\S ]+\</s',  // strip whitespaces before tags, except space
			'/(\s)+/s'       // shorten multiple whitespace sequences
		);
		$replace = array(
			'>',
			'<',
			'\\1'
		);
		$buffy = preg_replace($search, $replace, $buffy);

		$buffyArray = array(
			'bookmify_be_data' 		=> $buffy,
			
		);

		if ( true === $isAjaxCall ){die(json_encode($buffyArray));} 
		else{return json_encode($buffyArray);}
	}
	
	/**
	 * @since 1.0.0
	 * @access protected
	*/
	protected function get_page_title() {
		return esc_html__( 'Coupons', 'bookmify' );
	}
}
	

